@@ -92,7 +92,7 @@ simplify = transformBi fDecl . transformBi fMatch . transformBi fPat . transform
             where x2 = Var $ UnQual x
         fExp (Case (ExpTypeSig _ x@Lit{} _) alts) = fExp $ Case x alts
         fExp (Case (Lit x) alts) | good /= [] = head good
-            where good = [z | Alt _ (PLit Signless y) (UnGuardedRhs z) (BDecls []) <- alts, y == x]
+            where good = [z | Alt _ (PLit Signless y) (UnGuardedRhs z) Nothing <- alts, y == x]
         fExp (If x t f)
             | x ~= "True" = t
             | x ~= "False" = f
@@ -124,7 +124,7 @@ simplify = transformBi fDecl . transformBi fMatch . transformBi fPat . transform
 
         fMatch (Match sl nam pat sig (GuardedRhss [GuardedRhs _ [Qualifier x] bod]) decls)
             | x ~= "True" = fMatch $ Match sl nam pat sig (UnGuardedRhs bod) decls
-        fMatch (Match sl nam [PVar x] sig (UnGuardedRhs (Case (Var (UnQual x2)) [Alt _ pat (UnGuardedRhs y) (BDecls [])])) decls)
+        fMatch (Match sl nam [PVar x] sig (UnGuardedRhs (Case (Var (UnQual x2)) [Alt _ pat (UnGuardedRhs y) Nothing])) decls)
             | x == x2 = fMatch $ Match sl nam [PParen pat] sig (UnGuardedRhs y) decls
         fMatch o@(Match a b c d e bind) = fBinds (Match a b (minPat o c) d e) bind
 
@@ -132,19 +132,21 @@ simplify = transformBi fDecl . transformBi fMatch . transformBi fPat . transform
         fDecl (FunBind xs) = FunBind $ filter (not . isGuardFalse) xs
         fDecl x = x
 
-        fBinds context (BDecls bind) | inline /= [] =
-                simplify $ subst (Var $ UnQual from) to $ context $ BDecls $ take i bind ++ drop (i+1) bind
+        fBinds context Nothing = context Nothing
+        fBinds context (Just (BDecls bind)) | inline /= [] =
+                simplify $ subst (Var $ UnQual from) to $ context $
+                    let xs = take i bind ++ drop (i+1) bind in if null xs then Nothing else Just $ BDecls xs
             where
-                f (PatBind _ (PVar x) (UnGuardedRhs bod) (BDecls [])) = [(x,bod)]
-                f (FunBind [Match _ x [PVar v] Nothing (UnGuardedRhs (Paren (App bod (Var v2)))) (BDecls [])])
+                f (PatBind _ (PVar x) (UnGuardedRhs bod) Nothing) = [(x,bod)]
+                f (FunBind [Match _ x [PVar v] Nothing (UnGuardedRhs (Paren (App bod (Var v2)))) Nothing])
                     | UnQual v == v2 = [(x,bod)]
-                f (FunBind [Match sl x pat Nothing (UnGuardedRhs bod) (BDecls [])]) = [(x,Paren $ Lambda sl pat bod)]
+                f (FunBind [Match sl x pat Nothing (UnGuardedRhs bod) Nothing]) = [(x,Paren $ Lambda sl pat bod)]
                 f _ = []
 
                 (i,from,to) = head inline
                 inline = [(i, x, bod)
                          | (i,b) <- zip [0..] bind, (x,bod) <- f b
-                         , isAtom bod || once (Var $ UnQual x) (context $ BDecls bind)]
+                         , isAtom bod || once (Var $ UnQual x) (context $ Just $ BDecls bind)]
         fBinds a y = a y
 
         subst from to = transformBi $ \x -> if x == from then to else x
@@ -235,8 +237,8 @@ bind :: String -> [Pat] -> Exp -> Decl
 bind s p e = binds s [(p,e)]
 
 binds :: String -> [([Pat], Exp)] -> Decl
-binds n [([],e)] = PatBind sl (pVar n) (UnGuardedRhs e) (BDecls [])
-binds n xs = FunBind [Match sl (name n) p Nothing (UnGuardedRhs e) (BDecls []) | (p,e) <- xs]
+binds n [([],e)] = PatBind sl (pVar n) (UnGuardedRhs e) Nothing
+binds n xs = FunBind [Match sl (name n) p Nothing (UnGuardedRhs e) Nothing | (p,e) <- xs]
 
 
 isDataDecl :: Decl -> Bool
